==> haskell-hls-stylish-haskell-plugin-2.1.0.0-101-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-stylish-haskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-stylish-haskell-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-stylish-haskell-plugin-2.1.0.0-EVTuyCC2w554WQbgcgHRmY
key:                  hls-stylish-haskell-plugin-2.1.0.0-EVTuyCC2w554WQbgcgHRmY
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Stylish Haskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  1396427a3ece08cdbb997ffd3160ffee
exposed:              True
exposed-modules:      Ide.Plugin.StylishHaskell
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-stylish-haskell-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-stylish-haskell-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-stylish-haskell-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-stylish-haskell-plugin
hs-libraries:         HShls-stylish-haskell-plugin-2.1.0.0-EVTuyCC2w554WQbgcgHRmY
depends:
    base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1 ghc-9.6.6
    ghc-boot-th-9.6.6 ghcide-2.1.0.0-BlCpiz4ZHvtIqUTiKV6UyX
    hls-plugin-api-2.1.0.0-IyHsVCiLch7D25xEM5t6Zs
    lsp-types-2.0.1.0-KsWoulY9wwoKMSLEqbLHCK mtl-2.3.1
    stylish-haskell-0.14.5.0-867ODiQlVl4Iv8SKhke8Gj text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-stylish-haskell-plugin/html/hls-stylish-haskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-stylish-haskell-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-stylish-haskell-plugin-2.1.0.0-102-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-stylish-haskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-stylish-haskell-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-stylish-haskell-plugin-2.1.0.0-JvagB5X92xWNtzj1QedcC
key:                  hls-stylish-haskell-plugin-2.1.0.0-JvagB5X92xWNtzj1QedcC
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Stylish Haskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  86bd050eb5c8f7d3ada37b12b77a0d6e
exposed:              True
exposed-modules:      Ide.Plugin.StylishHaskell
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-stylish-haskell-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-stylish-haskell-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-stylish-haskell-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-stylish-haskell-plugin
hs-libraries:         HShls-stylish-haskell-plugin-2.1.0.0-JvagB5X92xWNtzj1QedcC
depends:
    base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1 ghc-9.6.6
    ghc-boot-th-9.6.6 ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    lsp-types-2.0.1.0-KsWoulY9wwoKMSLEqbLHCK mtl-2.3.1
    stylish-haskell-0.14.5.0-867ODiQlVl4Iv8SKhke8Gj text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-stylish-haskell-plugin/html/hls-stylish-haskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-stylish-haskell-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
